@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-combinators
 version: 1.0.3.1
-id: conduit-combinators-1.0.3.1-4df458d222c24e4d94af85e4b0c56c7e
-key: condu_CNm6DZXsV5O4ingT20oTp9
+id: conduit-combinators-1.0.3.1-ee222ddee1ed14b6cdad38c9d97b4ded
+key: condu_4tDpfLDax5e9x8zsObC2KJ
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/conduit-combinators
@@ -21,21 +21,21 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
-hs-libraries: HSconduit-combinators-1.0.3.1-CNm6DZXsV5O4ingT20oTp9
+hs-libraries: HSconduit-combinators-1.0.3.1-4tDpfLDax5e9x8zsObC2KJ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    chunked-data-0.2.0-4e0b1e7ec0ddce94d0cbc9c24739d039
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
+    chunked-data-0.2.0-0e06c4c78d0115de9d8c000bb08df0f5
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    mono-traversable-0.10.1.1-444d89c530a7a69af62384c66ba2d700
+    mono-traversable-0.10.1.1-7ac62162d55f8d714083ba886bfb5efd
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
